#!/bin/bash

##############################################################################################################
########################## Automatic creation of the system for protein APR calculations #####################
##############################################################################################################
#
# Instructions: 
#
# 1- Align crystal structure of the complex with the file ./pdbs/reference.pdb using MultiSeq (STAMP) from VMD, and write the pdb file like Crys-aligned.pdb (Crys being the PDB ID)
#
# 2- Copy the aligned pdb file to a new folder, together with the automated.bash script
#
# 3- Go to the new folder and run the 4 commands in the beginning of the automated.bash script into the terminal
#
# 4- In the same folder, run the automated.bash file with the arguments below:
#
# ./automated.bash Crys Res Anch1 Anch2 Anch3 Dih1 Dih2 Dih3 Dih4 DihDef
# 
# Crys=PDB ID, Res=Ligand Name from PDB, Anch1-3=Ligand anchor atoms names, Dih1-4=Atoms names from ligand dihedral restraint (use even if DihDef = nd) 
#
# DihDef = (nd) Without ligand dihedral restraint,  (nw) with dihedral but no wall restraint (wall used for two-fold symmetry), (w) with both restraints
#
# 5- Folders starting with a and l are protein and ligand attachment, respectively, u is pulling windows and c ligand release in a separate box.
#
# 6- VMD, AMBER and openbabel have to be installed and in your path to run the scripts.
#
# 7- Analysis of the simulations to obtain the free energies are done using the ./analysis/get-results.bash script (instructions included in this file).  
#
# Be CaREFUL WiTH: 
#
# - When aligning the protein in VMD, the reference has to be opened first, so the coordinates of the new PDB file are changed according to the latter.
#
# - Always eliminate duplicate residues (one of them) in the initial aligned PDB file (A and B versions of the same residue). AMBER can't read them duplicated. 
#
# - Change non-standard atoms names written all uppercase in the PDB file. To assign correct parameters the second letter has to be lowercase.
#  (Ex: change chlorine atom name from CLA to ClA in the initial aligned PDB file)
#
# - For errors check the Solvate.log file at the a00 folder
#
# 
#

source /usr/local/amber16gnu/amber.sh 
export LD_LIBRARY_PATH="/usr/local/cuda-7.5/lib64:$LD_LIBRARY_PATH"
export AMBERHOME="/usr/local/amber16gnu/"
export PATH="/data/gheinzel/babel/openbabel-install/bin/:$PATH"

mkdir pdbs
cd pdbs
cp ../$1* ./
cp -r ../../Base-SPC/setup/ ../
cp -r ../../Base-SPC/run/ ../
cp ../../Base-SPC/pdbs/prep-orig-new.tcl ./
cp ../../Base-SPC/fore-* ../
cp prep-orig-new.tcl prep.tcl
sed -i "s/pppp/$1/g" prep.tcl
sed -i "s/MMM/$2/g" prep.tcl
sed -i "s/AA1/$3/g" prep.tcl
mol=$2
declare -l mol
mol=$mol
sed -i "s/mmm/$mol/g" prep.tcl
sed -i "s/mmm/$mol/g" ../run/RUN-ALL.bash
vmd -dispdev text -e prep.tcl
babel -i pdb $mol\.pdb -o pdb $mol-h.pdb -h
$AMBERHOME/AmberTools/bin/antechamber -i $mol-h.pdb -fi pdb -o $mol\.mol2 -fo mol2 -c bcc -s 2
$AMBERHOME/AmberTools/bin/parmchk -i $mol.mol2 -f mol2 -o $mol.frcmod
tail -n +2 "BRD4-$mol.pdb" > "BRD4-$mol.pdb.tmp" && mv "BRD4-$mol.pdb.tmp" "BRD4-$mol.pdb"
echo "REMARK A :70@CA :91@CA :117@CA :125@$3 :125@$4 :125@$5" | cat - BRD4-$mol\.pdb > temp && mv temp BRD4-$mol\.pdb
cp $mol\.pdb zzzz-$mol\.pdb  
tail -n +2 "zzzz-$mol.pdb" > "zzzz-$mol.pdb.tmp" && mv "zzzz-$mol.pdb.tmp" "zzzz-$mol.pdb"
echo "REMARK A :2000@O :2000@O :2000@O :4@$3 :4@$4 :4@$5" | cat - zzzz-$mol\.pdb > temp && mv temp zzzz-$mol\.pdb
cd ../
mkdir ff
cp ./pdbs/$mol\.mol2 ./ff/
cp ./pdbs/$mol\.frcmod ./ff/
cp ./pdbs/$mol-h.pdb ./ff/$mol\.pdb
cp fore-orig.pl foreach.pl
sed -i "s/mmm/$mol/g" ./foreach.pl
cp ./setup/SETUP-Rest-orig.pl ./setup/SETUP-Restraints.pl
sed -i "s/DD1/$6/g" ./setup/SETUP-Restraints.pl
sed -i "s/DD2/$7/g" ./setup/SETUP-Restraints.pl
sed -i "s/DD3/$8/g" ./setup/SETUP-Restraints.pl
sed -i "s/DD4/$9/g" ./setup/SETUP-Restraints.pl
sed -i "s/mmm/$mol/g" ./setup/SETUP-Restraints.pl
cp ./setup/SETUP-Solv-orig.pl ./setup/SETUP-Solvate.pl
sed -i "s/mmm/$mol/g" ./setup/SETUP-Solvate.pl
sed -i "s/MMM/$2/g" ./setup/SETUP-Solvate.pl
cp ./setup/Solv-orig.in ./setup/Solvate.in
sed -i "s/mmm/$mol/g" ./setup/Solvate.in
sed -i "s/MMM/$2/g" ./setup/Solvate.in
if [ ${10} == 'nw' ]
then
sed -i "/\$rst\[16\]/c\$rst\[16\]=':5000@O :5000@O :5000@O :5000@O';" ./setup/SETUP-Restraints.pl
fi
if [ ${10} == 'nd' ]
then
sed -i "/\$rst\[16\]/c\$rst\[16\]=':5000@O :5000@O :5000@O :5000@O';" ./setup/SETUP-Restraints.pl
sed -i "/\$rst\[12\]/c\$rst\[12\]=':5000@O :5000@O :5000@O :5000@O';" ./setup/SETUP-Restraints.pl
fi

perl foreach.pl

